@@ -12,9 +12,11 @@ class StringDatetimeValidator(OverridesStringFormatterValidator):
        A string in the format YYYYMMDD or
        (now|today|yesterday|date)[+-][0-9](microsecond|second|minute|hour|day|week|month|year)(s)
 
-    Valid examples are ``now-2weeks`` or ``20200101``. Can use override variables in this.
-    Note that yt-dlp will round times to the closest day, meaning that `day` is the lowest
-    granularity possible.
+    Valid examples are ``now-2weeks`` or ``20200101``. Can use override variables in
+    this. Note that yt-dlp will round times to the closest day, meaning that `day` is
+    the lowest granularity possible. Also note that, considering time zones, it's best
+    to include a margin of an extra day on either side to be sure it includes the
+    intended download files.
     """
 
     _expected_value_type_name = "datetime string"
